function saliency = FixationMap( szImg, fixations, sig )
% FixationMap - compute fixation map
%
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy
% of this software and associated documentation files (the "Software"), to deal
% in the Software without restriction, subject to the following conditions:
% 
% The above copyright notice and this permission notice shall be included in 
% all copies or substantial portions of the Software.
%
% The Software is provided "as is", without warranty of any kind.

    if exist( 'sig', 'var' )~=1 || isempty( sig )
        sig = szImg(1)/10;
    end
    
    saliency = zeros( szImg(1:2) );
    
    [X,Y] = meshgrid( 1:szImg(2), 1:szImg(1) );
    
    Z = 1/( 2*pi*sig.^2 );
    
    nFixations = size( fixations, 1 );
    for i=1:nFixations
        ux = fixations( i, 1 );
        uy = fixations( i, 2 );
        
        dst = Z .* exp( - ( (X-ux).^2 + (Y-uy).^2 ) ./ (2*sig.^2) );
        
        saliency = saliency + dst;
    end
    
    saliency = saliency ./ max( saliency(:) );
end
