function Torque = computeTorqueForAttention( im )
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/

    % parameters
    thresh    = 0.1;
    sigma     = 2;
    num       = 500;
    patchList = (3:2:51)';

    im = rgb2gray( double(im)/255.0 );

    warning( 'off', 'Images:isrgb:obsoleteFunction' );
    pb = pbCanny( im, sigma );
    warning( 'on', 'Images:isrgb:obsoleteFunction' );
    edgeS = (pb>thresh);
    
    % compute edge direction
    sig = 0.5;
    delt = 1e-5;
    WH = sqrt(2*sig^2*(-log(sqrt(2*pi)*sig*delt)));
    H = fspecial('gaussian',2*ceil(WH)+1,sig);
    imGraySmoothed = imfilter( im, H );
    [gx,gy] = gradient( imGraySmoothed );
    theta = atan2( -gx, gy );
    theta( gx==0 & gy==0 ) = NaN;
    
    % split edges into eight directions
    theta = theta + pi/8.0;
    theta(theta<0) = theta(theta<0) + 2.0*pi;
    edges = zeros([size(edgeS),8]);
    for i=1:8
        mask = ( theta>=(i-1)/8.0*2.0*pi & theta<i/8.0*2.0*pi );
        edges(:,:,i) = edgeS .* mask;
    end
    
    % torque volume
    szEdges = size(edges);
    
	weights = findWeights(edges);
	replicatedWeights = repmat(weights, [1 1 8]);
	weightedEdges = edges .* replicatedWeights;

	sumEdges = integralStackImage(weightedEdges);

    momentArms = makeMomentArms(szEdges(1), szEdges(2));
	moments = momentArms .* weightedEdges;
	sumMoments = integralStackImage(moments);

	torqueVolume = findMomentScaleStack_modified( momentArms, sumEdges, sumMoments, patchList );
    
    maxFlags = find3DMax( torqueVolume, patchList);
    minFlags = find3DMax(-torqueVolume, patchList);

    maxStack = torqueVolume .*maxFlags;
    minStack = torqueVolume .*minFlags;
    
    torqueMaxSorted = sortPatches( maxStack, patchList, num );
    torqueMinSorted = sortPatches(-minStack, patchList, num );
    
    Torque.torqueMaxSorted          = torqueMaxSorted;
    Torque.torqueMinSorted          = torqueMinSorted;
