% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/

clear
close all
clc

addpath( genpath( '../gbvs/' ) );
addpath( genpath( '../segbench/' ) );
addpath ../MAX-MOMENTS-PATCHES/
addpath ../EyeTracking/DatabaseCode/
addpath ../common/

dirEyeTracking = '../EyeTracking/';

%% eye tracking data
dirEyeTrackingData  = sprintf( '%sDATA', dirEyeTracking );
dirEyeTrackingImage = sprintf( '%sALLSTIMULI', dirEyeTracking );

files = dir( dirEyeTrackingData );
subjects = cell( 1, length(files) );
nSubjects = 0;
for i=1:length(files)
    if files(i).isdir
        if ~strcmpi( files(i).name, '.' ) &&...
           ~strcmpi( files(i).name, '..' ) &&...
           ~strcmpi( files(i).name, '.DS_Store' )

            nSubjects = nSubjects + 1;
            subjects{nSubjects} = files(i).name;
        end
    end
end
subjects_tmp = cell( 1, nSubjects );
[subjects_tmp{1:nSubjects}] = subjects{1:nSubjects};
subjects = subjects_tmp;

randIdx = 1:1003;
flgAvailable = true(1,length(randIdx));


iImage = 1; % index to test data

%% extract fixation points
appropFixAll = [];
for iSubject=1:nSubjects

    files=dir( fullfile( dirEyeTrackingData, subjects{iSubject}, '*.mat' ) );
    filenames = cell(1,size(files,1));
    [filenames{1:size(files,1)}] = deal(files.name);

    load( fullfile( dirEyeTrackingData, subjects{iSubject}, filenames{iImage} ) );

    stimFile = eval( filenames{iImage}(1:end-4) );

    if ~isfield( stimFile, 'imgName' )
        error( 'not avairable' );
    end

    if iSubject==1
        imgName = stimFile.imgName;
        if exist( fullfile( dirEyeTrackingImage, imgName ), 'file' ) == 2
            img = imread( fullfile( dirEyeTrackingImage, imgName ) );
        end
        fprintf( 'test image: %s\n', imgName );
    else
        if ~strcmpi( imgName, stimFile.imgName )
            error( 'image different' );
        end
    end

    % Load eye data & analyze fixations:
    eyeData = stimFile.DATA(1).eyeData;
    [eyeData Fix Sac] = checkFixations(eyeData);
    fixs = find(eyeData(:,3)==0);

    appropFix = floor(Fix.medianXY(2:end, :));  % we start at fixation 2

    appropFixAll = [appropFixAll; appropFix]; %#ok<AGROW>
end

%% prepare test image
outW = 150;
if size(img,1)>size(img,2)
    scaleFactor = outW/size(img,2);
else
    scaleFactor = outW/size(img,1);
end
ims = imresize( img , scaleFactor, 'bicubic' );  

%% ground truth
sig = 25;%size(ims,1)/3;
attentionTruth = FixationMap( size(ims), scaleFactor.*appropFixAll, sig );

%% Itti&Koch and Graph-base visual attention
params = makeGBVSParams;

params.useIttiKochInsteadOfGBVS = 1;
attentionIttiKoch = gbvs( ims, params );

attentionGBVS     = gbvs( ims );

%% Torque attention

% compute torque
Torque = computeTorqueForAttention( ims );

torqueExtremaSorted = [Torque.torqueMaxSorted; Torque.torqueMinSorted];
[tmp, idx] = sort( torqueExtremaSorted(:,5), 1, 'descend' );
torqueExtremaSorted = torqueExtremaSorted( idx, : );

idxs = selectAttention( torqueExtremaSorted, [], 3 );

numFixs = min( length(idxs), 500 );
attentionTorque = FixationMap( size(ims), [torqueExtremaSorted(idxs(1:numFixs),2), torqueExtremaSorted(idxs(1:numFixs),1)], 25 );

alpha = 0.3;    % blending factor for GBVS+Torque
attentionGBVSTorq = alpha .* attentionTorque + (1-alpha) .* attentionGBVS.master_map_resized;

%% evaluation

threshTruth = 0.5;
nSamples    = 100;
beta        = 1.0;

[PItti,     RItti,     FItti,     TpFpTnFnItti    ] = evalAttention( attentionIttiKoch.master_map_resized, attentionTruth, threshTruth, nSamples, beta );
[PGBVS,     RGBVS,     FGBVS,     TpFpTnFnGBVS    ] = evalAttention( attentionGBVS.master_map_resized,     attentionTruth, threshTruth, nSamples, beta );
[PTorq,     RTorq,     FTorq,     TpFpTnFnTorq    ] = evalAttention( attentionTorque,                      attentionTruth, threshTruth, nSamples, beta );
[PGBVSTorq, RGBVSTorq, FGBVSTorq, TpFpTnFnGBVSTorq] = evalAttention( attentionGBVSTorq,                    attentionTruth, threshTruth, nSamples, beta );

%% visualization
oimIttiKoch   = overlayAttention( ims, attentionIttiKoch.master_map_resized );
oimGBVS       = overlayAttention( ims, attentionGBVS.master_map_resized     );
oimTorque     = overlayAttention( ims, attentionTorque                      );
oimGBVSTorque = overlayAttention( ims, attentionGBVSTorq                    );
oimTruth      = overlayAttention( ims, attentionTruth                       );

figure( 'Position', [ 10, 40, 630, 650] );

subplot(3,2,1);
imshow( oimIttiKoch );
hold on;
plot( appropFixAll(:,1)*scaleFactor, appropFixAll(:,2)*scaleFactor, 'gx', 'MarkerSize', 5 );
hold off;
title('Itti & Koch');

subplot(3,2,2);
imshow( oimGBVS );
hold on;
plot( appropFixAll(:,1)*scaleFactor, appropFixAll(:,2)*scaleFactor, 'gx', 'MarkerSize', 5 );
hold off;
title('GBVS');

subplot(3,2,3);
imshow( oimTorque );
hold on;
plot( appropFixAll(:,1)*scaleFactor, appropFixAll(:,2)*scaleFactor, 'gx', 'MarkerSize', 5 );
hold off;
title('Torque');

subplot(3,2,4);
imshow( oimGBVSTorque );
hold on;
plot( appropFixAll(:,1)*scaleFactor, appropFixAll(:,2)*scaleFactor, 'gx', 'MarkerSize', 5 );
hold off;
title('GBVS+Torque');

subplot(3,2,5);
imshow( oimTruth );
hold on;
plot( appropFixAll(:,1)*scaleFactor, appropFixAll(:,2)*scaleFactor, 'gx', 'MarkerSize', 5 );
hold off;
title('Ground Trueth');

figure( 'Position', [650, 40, 630, 650] );

subplot( 2, 2, 1 );
plotPR( RItti, PItti, FItti );
title( 'Itti&Kich' );

subplot( 2, 2, 2 );
plotPR( RGBVS, PGBVS, FGBVS );
title( 'GBVS' );

subplot( 2, 2, 3 );
plotPR( RTorq, PTorq, FTorq );
title( 'Torque' );

subplot( 2, 2, 4 );
plotPR( RGBVSTorq, PGBVSTorq, FGBVSTorq );
title( 'GBVS+Torque' );
