function [pre,rec,F,TpFpTnFn] = evalAttention( attention, attentionTruth, threshTruth, nSamples, beta )
% evaluateAttention - evaluate attention
%
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy
% of this software and associated documentation files (the "Software"), to deal
% in the Software without restriction, subject to the following conditions:
% 
% The above copyright notice and this permission notice shall be included in 
% all copies or substantial portions of the Software.
%
% The Software is provided "as is", without warranty of any kind.

    if exist( 'nSamples', 'var' )~=1 || isempty( nSamples )
        nSamples = 10;
    end

    if exist( 'threshTruth', 'var' )~=1 || isempty( threshTruth )
        threshTruth = 0.5;
    end

    if exist( 'beta', 'var' )~=1 || isempty( beta )
        beta = 1;
    end

    groundtruth = attentionTruth > threshTruth;
    
    pre = NaN(nSamples,1);
    rec = NaN(nSamples,1);
    TpFpTnFn = NaN(nSamples,4);
    
    for iThresh=1:nSamples
        th = iThresh/(nSamples+1);
        test = attention > th;
        
        tp = length( find(  groundtruth &  test ) );
        fp = length( find( ~groundtruth &  test ) );
        fn = length( find(  groundtruth & ~test ) );
        tn = length( find( ~groundtruth & ~test ) );
    
        pre(iThresh) = tp / ( tp + fp );
        rec(iThresh) = tp / ( tp + fn );
        
        TpFpTnFn(iThresh,:) = [tp,fp,tn,fn];
    end
    
    F = computeFbeta( pre, rec, beta );
end

