function [sumEdgeContribution] = computeEdgeCont( edges, pt, patchSize, axesHandle )
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/

    if exist( 'axesHandle', 'var' ) ~= 1
        axesHandle = [];
    end

    szEdges = size(edges);

	weights = findWeights(edges);
	replicatedWeights = repmat(weights, [1 1 8]);
	weightedEdges = edges .* replicatedWeights;

    momentArms = makeMomentArms(szEdges(1), szEdges(2));

    sumEdgeContribution = zeros( szEdges );
    
    for i=1:size(pt,1)
        width = patchSize(i);
        
        halfSize = floor(0.5 * width);

        normalizer = 2 * width * width;

        momentArmsFromCenter = momentArms - repmat(momentArms(pt(i,2),pt(i,1),:), szEdges(1:2));
        edgeContribution = momentArmsFromCenter .* weightedEdges;

        edgeContribution = edgeContribution/normalizer;

        edgeContribution(1:max(1,pt(i,2)-halfSize-1),:,:) = 0;
        edgeContribution(:,1:max(1,pt(i,1)-halfSize-1),:) = 0;
        edgeContribution(min(pt(i,2)+halfSize+1,szEdges(1)):end,:,:) = 0;
        edgeContribution(:,min(pt(i,1)+halfSize+1,szEdges(2)):end,:) = 0;

        sumEdgeContribution = sumEdgeContribution + edgeContribution;
        
        if ~isempty( axesHandle )
            axes( axesHandle );
            imagesc( sum(sumEdgeContribution,3) );
            colormap gray
            axis image;
            axis off
            title( sprintf( 'number of points %d', i ) );
            drawnow;
        end
    end
    