% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/

clear
close all
clc

addpath( genpath( '../segbench/' ) );
addpath ../MAX-MOMENTS-PATCHES/
addpath ../GCmex1.9/
addpath ../common/

dirDataImage = '../occlusion_dataset_v1/ref_frames/';
dirDataTruth = '../occlusion_dataset_v1/ground_truth_objects/';


%% test image
dataName = 'trash';
fname = sprintf( '%s%s.tif', dirDataImage, dataName );
img = imread( fname );
img = double(img)/255.0;    

outW = 150;
if size(img,1)>size(img,2)
    scaleFactor = outW/size(img,2);
else
    scaleFactor = outW/size(img,1);
end
ims = imresize( img , scaleFactor, 'bicubic' );  
ims = max(0,min(1,ims));

%% ground truth & fixation point
fname = sprintf( '%s%s_objects.mat', dirDataTruth, dataName );
load( fname );

% object selection
fixPt = [324,336];  % rough position of object
depthMax = 0;
jMax = 0;
for j=1:size(objects,3)
    depth = objects( fixPt(1), fixPt(2), j );
    if depth > depthMax
        depthMax = depth;
        jMax = j;
    end
end 
if depthMax == 0
    error( 'wrong selection\n' )
end

% center of object as fixtation point
labels = objects(:,:,jMax);
labels(labels~=0) = 1;
labels = imresize( double(labels), [size(ims,1),size(ims,2)], 'bicubic' );
labels(labels< 0.5) = 0;
labels(labels>=0.5) = 1;
[X,Y] = meshgrid( 1:size(labels,2), 1:size(labels,1) );
p = find( labels~=0 );
ptCenter = round( [mean(X(p)); mean(Y(p))] );

%% torque
Torque = computeTorqueForSegmentation( ims );

%% segmentation
segs = cell(1,2);
segs{1} = segmentFixation( ptCenter, Torque.pbEdges );
segs{2} = segmentFixation( ptCenter, Torque.pbTorque );

%% evaluation
covering = NaN(2,1);
for k = 1:2
    seg = segs{k};
    seg(isnan(seg)) = 0;
    covering(k) = length( find(  labels &  seg ) ) ./ length( find( labels |  seg ) );
end
fprintf( 'Canny:  covering %7.3f\n', covering(1) );
fprintf( 'Torque: covering %7.3f\n', covering(2) );

%% visualization
figure( 'Position', [ 100, 80, 800, 400] );

subplot( 2, 3, 1 );
imshow( ims );
title( 'test image' );

subplot( 2, 3, 2 );
imagesc( Torque.pbEdges );
colormap gray;
axis image;
axis off;
title( 'Canny edge map' );

subplot( 2, 3, 3 );
imagesc( Torque.pbTorque );
colormap gray;
axis image;
axis off;
title( 'Torque (strengthen) edge map' );

subplot( 2, 3, 4 );
imshow( ims.*repmat( labels==1, [1,1,3] ) );
axis image
hold on
plot( ptCenter(1), ptCenter(2), 'g.' );
contour( labels==1, 'linecolor', 'r' );
hold off
title( 'Ground Truth' );

subplot( 2, 3, 5 );
axis image
imshow( ims.*repmat( segs{1}==1, [1,1,3] ) );
hold on
plot( ptCenter(1), ptCenter(2), 'g.' );
contour( segs{1}==1, 'linecolor', 'r' );
hold off
title( 'segmentation based on Canny' );

subplot( 2, 3, 6 );
axis image
imshow( ims.*repmat( segs{2}==1, [1,1,3] ) );
hold on
plot( ptCenter(1), ptCenter(2), 'g.' );
contour( segs{2}==1, 'linecolor', 'r' );
hold off
title( 'segmentation based on torque' );
