function seg = segmentFixation( pt, edges ) 
% Copyright (c) 2011-2011 Morimichi Nishigaki
% Department of Computer Science
% The University of Maryland
% http://www.cs.umd.edu/

    szCart = size(edges);
    szPolar = [360,360];
    
    rmax = sqrt( max(pt(1)-1,szCart(2)-pt(1)).^2 + max(pt(2)-1,szCart(1)-pt(2)).^2 );
    
    X = NaN( szPolar(1), szPolar(2) );
    Y = NaN( szPolar(1), szPolar(2) );
    for x=1:szPolar(2)
        theta = 2*pi*(x-1)/szPolar(2);
        for y=1:szPolar(1)
            r = (y-1)/(szPolar(1)-1)*rmax;
            X(y,x) = r * cos( theta ) + pt(1);
            Y(y,x) = r * sin( theta ) + pt(2);
        end
    end
    [iX,iY] = meshgrid( 1:szCart(2), 1:szCart(1) );
    iX = iX-pt(1);
    iY = iY-pt(2);
    R = sqrt( iX.^2+iY.^2 )*(szPolar(1)-1)/rmax+1;
    W = atan2( iY, iX );
    W(W<0) = W(W<0) + 2*pi;
    W = W*szPolar(2)/(2*pi)+1;

    edgePolar = interp2( edges, X, Y );
    

    alpha  = 2e+2;
    beta   = 1e+0;
    weights = beta*exp( -alpha * edgePolar );
    weights(isnan(weights)) = 1e+15;

    % Data Cost
    DataCost = zeros(szPolar(1),szPolar(2),2);
    DataCost(  1,:,1) = 1e+15;
    DataCost(end,:,2) = 1e+15;

    DataCost = reshape( DataCost, [szPolar(1)*szPolar(2),2] )';
    
    % Smoothness Cost
    SmoothnessCost = flipud(eye(2));

    [X0,Y0] = meshgrid( 1:szPolar(2), 1:szPolar(1) );
    X1 = X0;
    Y1 = circshift( Y0, [-1,0] );
    szReshape = [(szPolar(1)-1)*szPolar(2),1];
    reshapeX0 = reshape(X0(1:end-1,:),szReshape);
    reshapeY0 = reshape(Y0(1:end-1,:),szReshape);
    reshapeX1 = reshape(X1(1:end-1,:),szReshape);
    reshapeY1 = reshape(Y1(1:end-1,:),szReshape);
    wV(:,1) = sub2ind( [szPolar(1),szPolar(2)], reshapeY0, reshapeX0 );
    wV(:,2) = sub2ind( [szPolar(1),szPolar(2)], reshapeY1, reshapeX1 );
    wV(:,3) = reshape( weights(1:end-1,:), szReshape );
    Y1 = Y0;
    X1 = circshift( X0, [0,-1] );
    wH(:,1) = sub2ind( [szPolar(1),szPolar(2)], Y0(:), X0(:) );
    wH(:,2) = sub2ind( [szPolar(1),szPolar(2)], Y1(:), X1(:) );
    wH(:,3) = weights(:);

    SparseSmoothness = sparse( [wV(:,1);wH(:,1);wV(:,2);wH(:,2)],...
                               [wV(:,2);wH(:,2);wV(:,1);wH(:,1)],...
                               [wV(:,3);wH(:,3);wV(:,3);wH(:,3)] ); 

    gch = GraphCut( 'open', DataCost, SmoothnessCost, SparseSmoothness );
    [gch L] = GraphCut( 'swap', gch );
    GraphCut( 'close', gch );

    L = reshape( L, [szPolar(1),szPolar(2)] );

    % eliminate segments not connected to source or drain
    [cc,ncc] = bwlabel(L==0,4);
    for i=1:szPolar(1)
        c1 = cc(i,1);
        c2 = cc(i,szPolar(2));
        if c1>0 && c2>0 && c1 ~= c2
            cc(cc==c2) = c1;
        end
    end
    for i=1:ncc
        p = find(cc==i);
        if ~any(DataCost(p+szPolar(1)*szPolar(2))>0)
            L(p) = 1;
        end
    end
    [cc,ncc] = bwlabel(L==1,4);
    for i=1:szPolar(1)
        c1 = cc(i,1);
        c2 = cc(i,szPolar(2));
        if c1>0 && c2>0 && c1 ~= c2
            cc(cc==c2) = c1;
        end
    end
    for i=1:ncc
        p = find(cc==i);
        if ~any(DataCost(p)>0)
            L(p) = 0;
        end
    end
    
    seg = interp2( double(L), W, R );
